(function($) {
    'use strict';

    /**
     * All of the code for your admin-facing JavaScript source
     * should reside in this file.
     *
     * Note: It has been assumed you will write jQuery code here, so the
     * $ function reference has been prepared for usage within the scope
     * of this function.
     *
     * This enables you to define handlers, for when the DOM is ready:
     *
     * $(function() {
     *
     * });
     *
     * When the window is loaded:
     *
     * $( window ).load(function() {
     *
     * });
     *
     * ...and/or other possibilities.
     *
     * Ideally, it is not considered best practise to attach more than a
     * single DOM-ready or window-load handler for a particular page.
     * Although scripts in the WordPress core, Plugins and Themes may be
     * practising this, we should strive to set a better example in our own work.
     * 
     */


    var app = angular.module('admin_user_app', ['ui.bootstrap', 'ngAnimate', 'datatables'], function($interpolateProvider) {
        $interpolateProvider.startSymbol('<#');
        $interpolateProvider.endSymbol('#>');
    });


    app.controller('admin_user_controller', function($scope, $http, $timeout, $compile, $rootScope, $element, $animate, DTOptionsBuilder, filterFilter) {

        $scope.dtOptions_users = {
            pageLength: 100,
            lengthMenu: [
                [100, 300, 500, -1],
                [100, 300, 500, "All"]
            ],
            order: [0, 'asc'],
            scrollY: 550,  
            scrollX: true
        }

        $scope.users = [];

        $scope.search_keywords = '';
        $scope.search_limit    = 5000;
        $scope.aus_searching_more_users = 0;

        // execute via keypress enter 
        $("#search_user_key").on('keypress',function(e) {
            if(e.which == 13) {
                $scope.search_users_exec();
            } // e.which 13

        });

        // execute via btn click
        $scope.search_users_btn = function(){
             $scope.search_users_exec();
        }


        // call main search user function, reset values
        $scope.search_users_exec = function(){
              
            if($scope.search_keywords){

                $scope.users = [];
                $scope.search_limit    = 100;
                $scope.aus_search_key  = Math.floor(Math.random() * 1000) + 10;

                $scope.search_users();    
                
            }else{

                Swal.fire(
                    'Oops!',
                    'Please enter something.',
                    'warning'
                )
            }

        }

        $scope.search_users = function(){
            
                var datas = new FormData();

                datas.append('action', 'prefix_post_search_users');
                datas.append('search_keyword',    $scope.search_keywords);
                datas.append('search_limit',      $scope.search_limit);
                datas.append('aus_search_key',    $scope.aus_search_key);

                jQuery.ajax({
                    url: search_users_url.url,
                    type: 'post',
                    data: datas,
                    processData: false, // Required for file upload
                    contentType: false, // Required for file upload
                    success: function(response) {

                        response = JSON.parse(response);
                        console.log(response);

                        if(response.continue == 1 && response.aus_search_key == $scope.aus_search_key ){
                            $timeout(function() {
                                $scope.users.push(...response.users);
                                $scope.search_users();
                            });
                            $scope.aus_searching_more_users = 1;
                        }else{
                            // stop loop post 
                            $timeout(function() {
                                $scope.users.push(...response.users);
                            });
                            $scope.aus_searching_more_users = 0;
                        }
                    },
                    error: function(response) {
                        // if timeout occur reduce the limit and search again.
                        $scope.search_limit /= 2;
                        $scope.search_users();
                    }
                }); //jQuery.ajax

        } // search_users

    });


})(jQuery);


